@@ -25,6 +25,11 @@ import xml.etree.ElementTree as ET
 from operator import attrgetter
 from pathlib import Path
 
+if sys.version_info < (3, 10):
+    from importlib_metadata import entry_points
+else:
+    from importlib.metadata import entry_points
+
 import pkg_resources
 from nexusformat.nexus import (NeXusError, NXdata, NXentry, NXfield, NXFile,
                                NXgroup, NXlink, NXobject, NXprocess, NXroot,
@@ -37,18 +42,18 @@ from .datadialogs import (AddDialog, CustomizeDialog, DirectoryDialog,
                           ExportDialog, InitializeDialog, InstallPluginDialog,
                           LimitDialog, LockDialog, LogDialog,
                           ManageBackupsDialog, NewDialog, PasteDialog,
-                          PlotDialog, PlotScalarDialog, PreferencesDialog,
-                          ProjectionDialog, RemovePluginDialog, RenameDialog,
-                          RestorePluginDialog, ScanDialog, SignalDialog,
-                          UnlockDialog, ViewDialog)
+                          PlotDialog, PlotScalarDialog, ProjectionDialog,
+                          RemovePluginDialog, RenameDialog,
+                          RestorePluginDialog, ScanDialog, SettingsDialog,
+                          SignalDialog, UnlockDialog, ViewDialog)
 from .fitdialogs import FitDialog
 from .plotview import NXPlotView
 from .pyqt import QtCore, QtGui, QtWidgets, getOpenFileName, getSaveFileName
 from .scripteditor import NXScriptWindow
 from .treeview import NXTreeView
-from .utils import (confirm_action, display_message, get_colors, get_name,
-                    import_plugin, is_file_locked, load_image, natural_sort,
-                    report_error, timestamp)
+from .utils import (confirm_action, define_mode, display_message, get_colors,
+                    get_name, import_plugin, is_file_locked, load_image,
+                    natural_sort, report_error, timestamp)
 
 
 class NXRichJupyterWidget(RichJupyterWidget):
@@ -190,6 +195,8 @@ class MainWindow(QtWidgets.QMainWindow):
         self.setWindowTitle('NeXpy v'+__version__)
         self.statusBar().showMessage('Ready')
 
+        self.app.app.paletteChanged.connect(self.change_mode)
+
         self.treeview.selection_changed()
         self.shellview.setFocus()
 
@@ -203,6 +210,9 @@ class MainWindow(QtWidgets.QMainWindow):
         from .plotview import active_plotview
         return active_plotview
 
+    def change_mode(self):
+        define_mode()
+
     # Populate the menu bar with common actions and shortcuts
     def add_menu_action(self, menu, action, defer_shortcut=False):
         """Add action to menu as well as self
@@ -385,9 +395,9 @@ class MainWindow(QtWidgets.QMainWindow):
 
         self.file_menu.addSeparator()
 
-        self.preferences_action = QtWidgets.QAction(
-            "Edit Preferences", self, triggered=self.edit_preferences)
-        self.add_menu_action(self.file_menu, self.preferences_action)
+        self.settings_action = QtWidgets.QAction(
+            "Edit Settings", self, triggered=self.edit_settings)
+        self.add_menu_action(self.file_menu, self.settings_action)
 
         self.quit_action = QtWidgets.QAction("&Quit", self,
                                              shortcut=QtGui.QKeySequence.Quit,
@@ -559,32 +569,68 @@ class MainWindow(QtWidgets.QMainWindow):
 
     def init_plugin_menus(self):
         """Add an menu item for every module in the plugin menus"""
+        plugins = {}
         self.plugin_names = set()
-        private_path = self.plugin_dir
-        if os.path.isdir(private_path):
-            for name in os.listdir(private_path):
-                if (os.path.isdir(os.path.join(private_path, name)) and
-                        not (name.startswith('_') or name.startswith('.'))):
-                    self.plugin_names.add(name)
-        public_path = pkg_resources.resource_filename('nexpy', 'plugins')
-        for name in os.listdir(public_path):
-            if (os.path.isdir(os.path.join(public_path, name)) and
-                    not (name.startswith('_') or name.startswith('.'))):
-                self.plugin_names.add(name)
+        private_path = Path(self.plugin_dir)
+        for plugin_path in private_path.iterdir():
+            plugin_name = plugin_path.name
+            if (plugin_path.is_dir() and not (plugin_name.startswith('_') or
+                                              plugin_name.startswith('.'))):
+                self.plugin_names.add(plugin_name)
+                logging.info(
+                    f'Installing "{plugin_name}" plugin from "{plugin_path}"')
+        public_path = Path(pkg_resources.resource_filename('nexpy', 'plugins'))
+        for plugin_path in public_path.iterdir():
+            plugin_name = plugin_path.name
+            if plugin_name.lower() in [p.lower() for p in self.plugin_names]:
+                logging.warning(
+                    f'Duplicate plugin "{plugin_name}" not installed\n'
+                    + 36 * ' ' + f'located in "{plugin_path}"')
+                continue
+            if (plugin_path.is_dir() and not (plugin_name.startswith('_') or
+                                              plugin_name.startswith('.'))):
+                self.plugin_names.add(plugin_name)
+                logging.info(
+                    f'Installing "{plugin_name}" plugin from "{plugin_path}"')
         plugin_paths = [private_path, public_path]
         for plugin_name in set(sorted(self.plugin_names)):
             try:
-                self.add_plugin_menu(plugin_name, plugin_paths)
+                plugin_module = import_plugin(plugin_name, plugin_paths)
+                plugins[plugin_name] = plugin_module.plugin_menu
             except Exception as error:
-                logging.info(
+                logging.warning(
                     f'The "{plugin_name}" plugin could not be added '
-                    'to the main menu\n' + 33*' ' + f'{error}')
+                    'to the main menu\n' + 36*' ' + f'Error: {error}')
+                self.plugin_names.remove(plugin_name)
+        for entry in entry_points(group='nexpy.plugins'):
+            plugin_name = entry.module.split('.')[-1]
+            if plugin_name.lower() in [p.lower() for p in self.plugin_names]:
+                logging.warning(
+                    f'Duplicate plugin "{entry.module}" not installed')
+                continue
+            else:
+                logging.info(
+                    f'Installing "{plugin_name}" '
+                    f'plugin from "{entry.module}" module')
+                self.plugin_names.add(plugin_name)
+            try:
+                plugins[plugin_name] = entry.load()
+            except Exception as error:
+                logging.warning(
+                    f'"{plugin_name}" could not be added to the main menu\n'
+                    + 36*' ' + f'Error: {error}')
+        for plugin in sorted(plugins):
+            try:
+                plugin_name, actions = plugins[plugin]()
+                self.add_plugin_menu(plugin_name, actions)
+            except Exception as error:
+                logging.warning(
+                    f'The "{plugin}" plugin could not be added '
+                    'to the main menu\n' + 36*' ' + f'Error: {error}')
 
-    def add_plugin_menu(self, plugin_name, plugin_paths):
-        plugin_module = import_plugin(plugin_name, plugin_paths)
-        name, actions = plugin_module.plugin_menu()
-        plugin_menu = self.menu_bar.addMenu(name)
-        for action in actions:
+    def add_plugin_menu(self, plugin_name, plugin_actions):
+        plugin_menu = self.menu_bar.addMenu(plugin_name)
+        for action in plugin_actions:
             self.add_menu_action(plugin_menu, QtWidgets.QAction(
                 action[0], self, triggered=action[1]))
 
@@ -849,9 +895,9 @@ class MainWindow(QtWidgets.QMainWindow):
                 self.add_menu_action(self.import_menu, import_action, self)
                 self.importer[import_action] = import_module
             except Exception as error:
-                logging.info(
+                logging.warning(
                     f'The "{import_name}" importer could not be added '
-                    'to the Import menu\n' + 33*' ' + f'{error}')
+                    'to the Import menu\n' + 36*' ' + f'Error: {error}')
 
     def new_workspace(self):
         try:
@@ -1847,12 +1893,12 @@ class MainWindow(QtWidgets.QMainWindow):
         except NeXusError as error:
             report_error("Resetting Plot Limits", error)
 
-    def edit_preferences(self):
+    def edit_settings(self):
         try:
-            dialog = PreferencesDialog(parent=self)
+            dialog = SettingsDialog(parent=self)
             dialog.show()
         except NeXusError as error:
-            report_error("Editing Preferences", error)
+            report_error("Editing Settings", error)
 
     def show_tree(self):
         self.raise_()
