@@ -15,9 +15,11 @@ import logging
 import os
 import re
 import sys
+import time
 import traceback as tb
 from configparser import ConfigParser
 from datetime import datetime
+from threading import Thread
 
 import numpy as np
 from IPython.core.ultratb import ColorTB
@@ -347,7 +349,7 @@ def format_float(value, width=6):
 
 def human_size(bytes, width=0, decimals=2):
     """Convert a file size to human-readable form"""
-    size = np.float(bytes)
+    size = float(bytes)
     for unit in [' B', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB']:
         if size < 1000.0 or unit == 'EB':
             break
@@ -414,7 +416,10 @@ def convertHTML(text):
     """Replaces ANSI color codes with HTML"""
     try:
         from ansi2html import Ansi2HTMLConverter
-        conv = Ansi2HTMLConverter(dark_bg=False, inline=True)
+        if in_dark_mode():
+            conv = Ansi2HTMLConverter(dark_bg=True, inline=True)
+        else:
+            conv = Ansi2HTMLConverter(dark_bg=False, inline=True)
         return conv.convert(text).replace('AAAAAA', 'FFFFFF')
     except ImportError:
         return ansi_re.sub('', text)
@@ -551,6 +556,19 @@ def parula_map():
     return LinearSegmentedColormap.from_list('parula', cm_data)
 
 
+def xtec_map():
+    """Generate a color map for use with the XTEC package.
+
+    The color map data is the same as the 'tab10' map, but with the lowest
+    value set to 'white'.
+    """
+    from matplotlib import colormaps
+    from matplotlib.colors import ListedColormap
+    cm_data = list(colormaps['tab10'].colors)
+    cm_data.insert(0, [1.0, 1.0, 1.0])
+    return ListedColormap(cm_data, name='xtec')
+
+
 def divgray_map():
     """New divergent color map copied from the registered 'gray' map."""
     if parse_version(mplversion) >= parse_version('3.5.0'):
@@ -617,8 +635,8 @@ def load_image(filename):
     return data
 
 
-def initialize_preferences(settings):
-    """Initialize NeXpy preferences.
+def initialize_settings(settings):
+    """Initialize NeXpy settings.
 
     For the nexusformat configuration parameters, precedence is given to
     those that are defined by environment variables, since these might
@@ -630,27 +648,27 @@ def initialize_preferences(settings):
     Parameters
     ----------
     settings : NXConfigParser
-        NXConfigParser instance containing NeXpy preferences.
+        NXConfigParser instance containing NeXpy settings.
     """
 
     def setconfig(parameter):
         environment_variable = 'NX_'+parameter.upper()
         if environment_variable in os.environ:
             value = os.environ[environment_variable]
-        elif settings.has_option('preferences', parameter):
-            value = settings.get('preferences', parameter)
+        elif settings.has_option('settings', parameter):
+            value = settings.get('settings', parameter)
         else:
             value = nxgetconfig(parameter)
         nxsetconfig(**{parameter: value})
-        settings.set('preferences', parameter, nxgetconfig(parameter))
+        settings.set('settings', parameter, nxgetconfig(parameter))
 
     for parameter in nxgetconfig():
         setconfig(parameter)
 
-    if settings.has_option('preferences', 'style'):
-        set_style(settings.get('preferences', 'style'))
+    if settings.has_option('settings', 'style'):
+        set_style(settings.get('settings', 'style'))
     else:
-        settings.set('preferences', 'style', 'default')
+        settings.set('settings', 'style', 'default')
 
     settings.save()
 
@@ -684,9 +702,57 @@ def set_style(style=None):
         use('default')
 
 
-class NXimporter:
+def in_dark_mode():
+    try:
+        from .consoleapp import _mainwindow
+        app = _mainwindow.app.app
+        return (app.palette().window().color().value() <
+                app.palette().windowText().color().value())
+    except Exception:
+        return False
+
+
+def define_mode():
+
+    from .consoleapp import _mainwindow
+    if in_dark_mode():
+        _mainwindow.console.set_default_style('linux')
+        _mainwindow.statusBar().setPalette(_mainwindow.app.app.palette())
+    else:
+        _mainwindow.console.set_default_style()
+        _mainwindow.statusBar().setPalette(_mainwindow.app.app.palette())
+
+    for dialog in _mainwindow.dialogs:
+        if dialog.windowTitle() == 'Script Editor':
+            for tab in [dialog.tabs[t] for t in dialog.tabs]:
+                tab.define_style()
+        elif dialog.windowTitle().startswith('Log File'):
+            dialog.format_log()
+
+    for plotview in _mainwindow.plotviews.values():
+        if in_dark_mode():
+            plotview.otab.setStyleSheet('color: white')
+        else:
+            plotview.otab.setStyleSheet('color: black')
+
+
+class NXListener(QtCore.QObject):
+
+    change_signal = QtCore.Signal(str)
+
+    def start(self, fn):
+        Thread(target=self.listen, args=(fn,), daemon=True).start()
+
+    def listen(self, fn):
+        fn(self)
+
+    def respond(self, signal):
+        self.change_signal.emit(signal)
+
+
+class NXImporter:
     def __init__(self, paths):
-        self.paths = paths
+        self.paths = [str(p) for p in paths]
 
     def __enter__(self):
         for path in reversed(self.paths):
@@ -698,7 +764,7 @@ class NXimporter:
 
 
 def import_plugin(name, paths):
-    with NXimporter(paths):
+    with NXImporter(paths):
         plugin_module = importlib.import_module(name)
         if hasattr(plugin_module, '__file__'):  # Not a namespace module
             return plugin_module
@@ -720,14 +786,13 @@ class NXConfigParser(ConfigParser, object):
             self.add_section('backups')
         if 'plugins' not in sections:
             self.add_section('plugins')
-        if 'preferences' not in sections:
-            self.add_section('preferences')
+        if 'settings' not in sections:
+            self.add_section('settings')
         if 'recent' not in sections:
             self.add_section('recent')
         if 'session' not in sections:
             self.add_section('session')
-        if 'recentFiles' in self.options('recent'):
-            self.fix_recent()
+        self.fix_compatibility()
 
     def set(self, section, option, value=None):
         if value is not None:
@@ -746,14 +811,20 @@ class NXConfigParser(ConfigParser, object):
         for option in self.options(section):
             self.remove_option(section, option)
 
-    def fix_recent(self):
-        """Perform backward compatibility fix"""
-        paths = [f.strip() for f
-                 in self.get('recent', 'recentFiles').split(',')]
-        for path in paths:
-            self.set("recent", path)
-        self.remove_option("recent", "recentFiles")
-        self.save()
+    def fix_compatibility(self):
+        """Perform backward compatibility fixes"""
+        if 'preferences' in self.sections():
+            for option in self.options('preferences'):
+                self.set('settings', option, self.get('preferences', option))
+            self.remove_section('preferences')
+            self.save()
+        if 'recentFiles' in self.options('recent'):
+            paths = [f.strip() for f
+                     in self.get('recent', 'recentFiles').split(',')]
+            for path in paths:
+                self.set("recent", path)
+            self.remove_option("recent", "recentFiles")
+            self.save()
 
 
 class NXLogger(io.StringIO):
